# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class UsAddress(UniversalBaseModel):
    first_line: str
    second_line: typing.Optional[str] = None
    city: str
    state: str
    zip_code: str
    unit: typing.Optional[str] = pydantic.Field(default=None)
    """
    Deprecated. Use `second_line` instead to provide the unit number. Subject to removal after 20 Nov 2023.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
