# This file was auto-generated by Fern from our API Definition.

from .types import LabTestsGetOrdersRequestOrderDirection, LabTestsGetOrdersRequestOrderKey

__all__ = ["LabTestsGetOrdersRequestOrderDirection", "LabTestsGetOrdersRequestOrderKey"]
