# This file was auto-generated by Fern from our API Definition.

import typing
from .date_trunc_expr import DateTruncExpr
from .date_part_expr import DatePartExpr

QueryInstructionGroupByItem = typing.Union[DateTruncExpr, DatePartExpr]
