# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClientFacingBodyTemperatureDeltaSampleSensorLocation(str, enum.Enum):
    ARMPIT = "armpit"
    BODY = "body"
    EAR = "ear"
    FINGER = "finger"
    GASTROINTESTINAL = "gastrointestinal"
    MOUTH = "mouth"
    RECTUM = "rectum"
    TOE = "toe"
    EARDRUM = "eardrum"
    TEMPORAL_ARTERY = "temporal_artery"
    FOREHEAD = "forehead"
    WRIST = "wrist"

    def visit(
        self,
        armpit: typing.Callable[[], T_Result],
        body: typing.Callable[[], T_Result],
        ear: typing.Callable[[], T_Result],
        finger: typing.Callable[[], T_Result],
        gastrointestinal: typing.Callable[[], T_Result],
        mouth: typing.Callable[[], T_Result],
        rectum: typing.Callable[[], T_Result],
        toe: typing.Callable[[], T_Result],
        eardrum: typing.Callable[[], T_Result],
        temporal_artery: typing.Callable[[], T_Result],
        forehead: typing.Callable[[], T_Result],
        wrist: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.ARMPIT:
            return armpit()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.BODY:
            return body()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.EAR:
            return ear()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.FINGER:
            return finger()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.GASTROINTESTINAL:
            return gastrointestinal()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.MOUTH:
            return mouth()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.RECTUM:
            return rectum()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.TOE:
            return toe()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.EARDRUM:
            return eardrum()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.TEMPORAL_ARTERY:
            return temporal_artery()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.FOREHEAD:
            return forehead()
        if self is ClientFacingBodyTemperatureDeltaSampleSensorLocation.WRIST:
            return wrist()
